/*
    SPDX-FileCopyrightText: 2019 Volker Krause <vkrause@kde.org>

    SPDX-License-Identifier: LGPL-2.0-or-later
*/

#pragma once

#include <config-kitinerary.h>
#include <qglobal.h>

using PopplerMaskColors = const int;
